# OiHelper

[![Test and Lint](https://img.shields.io/github/actions/workflow/status/ste1hi/OiRunner/main.yml?logo=github&label=Test%20and%20Lint)](https://github.com/ste1hi/OiRunner/actions/workflows/main.yml)
![last commit](https://img.shields.io/github/last-commit/ste1hi/OiRunner)
[![Codecov](https://img.shields.io/codecov/c/github/ste1hi/OiRunner)](https://app.codecov.io/gh/ste1hi/OiRunner)
![Static Badge](https://img.shields.io/badge/platform-Windows%20%7C%20Linux-yellow)
[![PyPI](https://img.shields.io/pypi/v/OiRunner)](https://pypi.org/project/OiRunner/)
![Python](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.12-blue)

This package is designed to help oier compile the cpp file conveniently.

## Feature

- Compile cpp file.
- Judge program result.
- Super easy to use, you don't need write more source code, just use in command line.

## Install
You can install this package via pip conveniently.

```bash
pip install OiRunner
```

## Basic Usage
You can use this module in command line.

```bash
oirun <your_program_file_name>
```

This command will compile your program file and run the executable file in command line directly.

## Advanced Usage

- [Judge program result](docs/judge.md)
- [Automatic operation](docs/automation.md)


# License
Copyright ste1hi, 2024.

Distributed under the terms of the [MIT License](./LICENSE).